@@ -1,13 +1,12 @@
 #' Create Records
 #' 
 #' @description
-#' \lifecycle{maturing}
+#' `r lifecycle::badge("maturing")`
 #' 
 #' Adds one or more new records to your organization’s data.
 #' 
 #' @importFrom lifecycle deprecate_warn is_present deprecated
-#' @param input_data \code{named vector}, \code{matrix}, \code{data.frame}, or 
-#' \code{tbl_df}; data can be coerced into a \code{data.frame}
+#' @template input_data
 #' @template object_name
 #' @template api_type
 #' @template guess_types
@@ -53,7 +52,8 @@ sf_create <- function(input_data,
   control_args$operation <- "insert"
   
   if(is_present(all_or_none)) {
-    deprecate_warn("0.1.3", "sf_create(all_or_none = )", "sf_create(AllOrNoneHeader = )", 
+    deprecate_warn("0.1.3", "salesforcer::sf_create(all_or_none = )", 
+                   "sf_create(AllOrNoneHeader = )", 
                    details = paste0("You can pass the all or none header directly ", 
                                     "as shown above or via the `control` argument."))
     control_args$AllOrNoneHeader <- list(allOrNone = tolower(all_or_none))
@@ -156,7 +156,7 @@ sf_create_soap <- function(input_data,
       xml_ns_strip() %>%
       xml_find_all('.//result') %>% 
       map_df(extract_records_from_xml_node)
-    resultset <- bind_rows(resultset, this_set)
+    resultset <- safe_bind_rows(list(resultset, this_set))
   }
   
   resultset <- resultset %>% 
