@@ -1,7 +1,7 @@
 #' Read Object or Field Metadata from Salesforce
 #' 
 #' @description
-#' \lifecycle{experimental}
+#' `r lifecycle::badge("experimental")`
 #' 
 #' This function takes a request of named elements in Salesforce and 
 #' returns their metadata
@@ -75,12 +75,12 @@ sf_read_metadata <- function(metadata_type, object_names, verbose=FALSE){
 #' Describe Object Fields
 #' 
 #' @description
-#' \lifecycle{maturing}
+#' `r lifecycle::badge("maturing")`
 #' 
 #' This function takes the name of an object in Salesforce and returns a description 
 #' of the fields on that object by returning a tibble with one row per field.
 #' 
-#' @importFrom dplyr bind_rows select
+#' @importFrom dplyr select
 #' @importFrom purrr map modify_at
 #' @template object_name
 #' @note The tibble only contains the fields that the user can view, as defined by 
@@ -97,14 +97,15 @@ sf_describe_object_fields <- function(object_name){
   
   obj_dat <- sf_describe_objects(object_names = object_name, api_type = "SOAP")[[1]]
   obj_fields_dat <- obj_dat[names(obj_dat) == "fields"] %>% 
-    # explicitly combine duplicated names because many tidyverse functions break whenever that occurs
+    # explicitly combine duplicated names because many tidyverse functions 
+    # break whenever that occurs
     map(collapse_list_with_dupe_names) %>% 
     map(set_null_elements_to_na)
   
   # check if all values are the same class (excluding NA)
   obj_fields_dat_classes <- obj_fields_dat %>% 
     map(~map(.x, class)) %>% 
-    bind_rows()
+    safe_bind_rows()
   
   classes_summary <- obj_fields_dat_classes %>% map_lgl(~length(unique(na.omit(.x))) > 1)
   if(any(classes_summary)){
@@ -116,7 +117,7 @@ sf_describe_object_fields <- function(object_name){
   # check if all values are of length 1, if not then cast as list if not already a list
   obj_fields_dat_lengths <- obj_fields_dat %>% 
     map(~map(.x, length)) %>% 
-    bind_rows()
+    safe_bind_rows()
   
   lengths_summary <- obj_fields_dat_lengths %>% map_lgl(~any(.x > 1, na.rm=TRUE))
   if(any(lengths_summary)){
@@ -126,7 +127,7 @@ sf_describe_object_fields <- function(object_name){
   }  
   
   obj_fields_dat <- obj_fields_dat %>% 
-    bind_rows() %>% 
+    safe_bind_rows() %>% 
     # sort column names as the API would return prior to the combining process above
     select(sort(names(.)))
   
@@ -164,7 +165,7 @@ collapse_list_with_dupe_names <- function(x){
       } else {
         collapsed <- obj_field_dupes %>% 
           map(set_null_elements_to_na) %>% 
-          bind_rows() %>%
+          safe_bind_rows() %>%
           list()
       }
       # replace into first
