@@ -1,14 +1,12 @@
 #' Retrieve Records By Id
 #' 
 #' @description
-#' \lifecycle{maturing}
+#' `r lifecycle::badge("maturing")`
 #' 
 #' Retrieves one or more new records to your organization’s data.
 #' 
-#' @param ids \code{vector}, \code{matrix}, \code{data.frame}, or 
-#' \code{tbl_df}; if not a vector, there must be a column called Id (case-insensitive) 
-#' that can be passed in the request
-#' @param fields character; one or more strings indicating the fields to be returned 
+#' @template ids
+#' @param fields \code{character}; one or more strings indicating the fields to be returned 
 #' on the records
 #' @template object_name
 #' @template api_type
@@ -130,7 +128,7 @@ sf_retrieve_soap <- function(ids,
              object_name_as_col = TRUE) %>% 
       # ignore record ids that could not be matched
       filter(across(any_of("Id"), ~!is.na(.x)))
-    resultset <- bind_rows(resultset, this_set)
+    resultset <- safe_bind_rows(list(resultset, this_set))
   }
   
   resultset <- resultset %>% 
