@@ -1,13 +1,12 @@
 #' Upsert Records
 #' 
 #' @description
-#' \lifecycle{maturing}
+#' `r lifecycle::badge("maturing")`
 #' 
 #' Upserts one or more new records to your organization’s data.
 #' 
 #' @importFrom lifecycle deprecate_warn is_present deprecated
-#' @param input_data \code{named vector}, \code{matrix}, \code{data.frame}, or 
-#' \code{tbl_df}; data can be coerced into a \code{data.frame}
+#' @template input_data
 #' @template object_name
 #' @template external_id_fieldname
 #' @template api_type
@@ -56,7 +55,8 @@ sf_upsert <- function(input_data,
   control_args$operation <- "upsert"
   
   if(is_present(all_or_none)) {
-    deprecate_warn("0.1.3", "sf_upsert(all_or_none = )", "sf_upsert(AllOrNoneHeader = )", 
+    deprecate_warn("0.1.3", "salesforcer::sf_upsert(all_or_none = )", 
+                   "sf_upsert(AllOrNoneHeader = )", 
                    details = paste0("You can pass the all or none header directly ", 
                                     "as shown above or via the `control` argument."))
     control_args$AllOrNoneHeader <- list(allOrNone = tolower(all_or_none))
@@ -248,7 +248,7 @@ sf_upsert_rest <- function(input_data,
     response_parsed <- content(httr_response, as="parsed", encoding="UTF-8")
     response_parsed <- response_parsed$results %>%
       map_df(~flatten_tbl_df(.x$result))
-    resultset <- bind_rows(resultset, response_parsed)
+    resultset <- safe_bind_rows(list(resultset, response_parsed))
   }
 
   resultset <- resultset %>% 
