@@ -5,6 +5,7 @@
 #' each record represents a row in the data frame.
 #' 
 #' @importFrom tibble as_tibble_row
+#' @importFrom purrr list_modify pluck
 #' @importFrom rlist list.flatten
 #' @param x \code{list}; a list to be extracted into a \code{tbl_df}.
 #' @return \code{tbl_df} parsed from the flattened list.
@@ -12,7 +13,21 @@
 #' @keywords internal
 #' @export
 flatten_tbl_df <- function(x){
-  x %>% list.flatten() %>% as_tibble_row()
+  
+  # set aside errors
+  errors <- x %>% pluck("errors")
+  
+  x_tbl <- x %>% 
+    list_modify("errors" = NULL) %>% 
+    list.flatten() %>% 
+    as_tibble_row()
+  
+  # convert errors to list column (since it can have multiple elements)
+  if(!is.null(errors)){
+    x_tbl$errors <- list(errors) 
+  }
+  
+  return(x_tbl)
 }
 
 #' Flatten list column
@@ -31,7 +46,7 @@ flatten_tbl_df <- function(x){
 unnest_col <- function(df, col){
   key_rows <- df %>% select(-all_of(col))
   col_data <- df %>% select(all_of(col))
-  bind_rows(
+  safe_bind_rows(
     lapply(1:nrow(key_rows), 
            FUN=function(x, y, z){
              key_record <- y[x,]
@@ -122,6 +137,46 @@ set_null_elements_to_na_recursively <- function(x) {
     set_null_elements_to_na()
 }
 
+#' Unlist all list elements of length 1 if they are not a list
+#' 
+#' This function wraps a simple \code{\link[purrr:modify]{modify_if}} function 
+#' to "unbox" list elements. This is helpful when the \code{\link[xml2]{as_list}} 
+#' returns elements of XML and the element value is kept as a list of length 1,
+#' even though it could be a single primitive data type (e.g. \code{logical},
+#' \code{character}, etc.).
+#' 
+#' @importFrom purrr modify_if
+#' @param x \code{list}; a list to be cleaned.
+#' @return \code{list} containing \code{NA} in place of \code{NULL} element values.
+#' @note This function is meant to be used internally. Only use when debugging.
+#' @keywords internal
+#' @export
+unbox_list_elements <- function(x){
+  x %>% 
+    modify_if(~((length(.x) == 1) && (!is.list(.x[[1]]))), 
+              .f = function(x){return(unlist(x))})  
+}
+
+#' Recursively unlist all list elements of length 1 if they are not a list
+#' 
+#' This function wraps a simple \code{\link[purrr:modify]{modify_if}} function 
+#' to recursively "unbox" list elements. This is helpful when the 
+#' \code{\link[xml2]{as_list}} returns elements of XML and the element value is 
+#' kept as a list of length 1, even though it could be a single primitive data 
+#' type (e.g. \code{logical}, \code{character}, etc.).
+#' 
+#' @importFrom purrr map_if
+#' @param x \code{list}; a list to be cleaned.
+#' @return \code{list} containing "unboxed" list elements.
+#' @note This function is meant to be used internally. Only use when debugging.
+#' @keywords internal
+#' @export
+unbox_list_elements_recursively <- function(x) {
+  x %>%
+    map_if(is.list, unbox_list_elements_recursively) %>% 
+    unbox_list_elements()
+}
+
 #' Remove Salesforce attributes data from list
 #' 
 #' This function removes elements from Salesforce data parsed to a list where 
@@ -257,10 +312,10 @@ xml_drop_and_unlist_recursively <- function(x) {
 #' This function accepts an \code{xml_node} assuming it already represents one 
 #' record and formats that node into a single row \code{tbl_df}.
 #' 
-#' @importFrom dplyr mutate_all as_tibble
+#' @importFrom dplyr tibble
 #' @importFrom tibble as_tibble_row
-#' @importFrom xml2 xml_find_all xml_text as_list xml_find_first xml_children xml_name xml_remove
-#' @importFrom purrr modify_if map_df
+#' @importFrom xml2 xml_find_all as_list xml_remove xml_find_first xml_text
+#' @importFrom purrr map
 #' @param node \code{xml_node}; the node to have records extracted into one row \code{tbl_df}.
 #' @param object_name_append \code{logical}; whether to include the object type
 #' (e.g. Account or Contact) as part of the column names (e.g. Account.Name).
@@ -277,15 +332,18 @@ extract_records_from_xml_node <- function(node,
   # TODO: Consider doing something with the duplicate match data because what is returned
   # in the duplicateResult element is very detailed. For now just remove it
   # if(length(xml_find_all(node, "//errors[@xsi:type='DuplicateError']")) > 0){
-  if(length(xml_find_first(node, "//errors | //error")) > 0){
-    children <- xml_find_first(node, "//errors | //error") %>% xml_children()
-    for(i in 1:length(children)){
-      if(!(xml_name(children[[i]]) %in% c("message", "statusCode", 
-                                          "errorMessage", "errorCode"))){
-        node_to_remove <- children[[i]]
-        xml_remove(node_to_remove)
-      }
-    }
+  error_nodes <- xml_find_all(node, ".//errors | .//error")
+  if(length(error_nodes) > 0){
+    errors_list <- error_nodes %>% 
+      # convert to list
+      as_list() %>%
+      # "unbox" length 1 list elements
+      map(unbox_list_elements_recursively) %>%
+      # return as a length 1 list, which is what the row requires (a single element)
+      list()
+    xml_remove(error_nodes)
+  } else {
+    errors_list <- list()
   }
   
   if(object_name_append | object_name_as_col){
@@ -295,9 +353,10 @@ extract_records_from_xml_node <- function(node,
   }
   
   if(length(node) > 0){
-    x <- as_list(node) %>% 
-      xml_drop_and_unlist_recursively() %>% 
-      drop_empty_recursively() %>% 
+    x <- node %>% 
+      as_list() %>%
+      xml_drop_and_unlist_recursively() %>%
+      drop_empty_recursively() %>%
       as_tibble_row()
     if(object_name_append){
       colnames(x) <- paste(object_name, colnames(x), sep='.')
@@ -308,6 +367,11 @@ extract_records_from_xml_node <- function(node,
   } else {
     x <- tibble()
   }
+  
+  if(length(errors_list) == 1){
+    x$errors <- errors_list
+  }
+  
   return(x)
 }
 
@@ -370,7 +434,8 @@ extract_records_from_xml_nodeset_of_records <- function(x,
                                                         object_name_append = FALSE, 
                                                         object_name_as_col = FALSE){
   if(length(x) > 0){
-    x_list <- as_list(x) %>% 
+    x_list <- x %>% 
+      as_list() %>% 
       map(xml_drop_and_unlist_recursively) %>% 
       map(drop_empty_recursively)
     x <- x_list %>% 
@@ -434,14 +499,14 @@ xml_extract_parent_and_child_result <- function(x){
 #' @export
 extract_nested_child_records <- function(x){
   
-  child_records <- x %>% 
-    map(pluck("records")) %>%  
+  child_records <- x %>%
+    map(pluck("records")) %>%
     map(~drop_attributes(.x, object_name_append = TRUE)) %>%
-    drop_attributes_recursively() %>% 
+    drop_attributes_recursively() %>%
     drop_empty_recursively() %>%
-    map_depth(2, flatten_tbl_df) %>% 
-    pluck(1) %>% 
-    bind_rows() %>% 
+    map_depth(2, flatten_tbl_df) %>%
+    pluck(1) %>%
+    safe_bind_rows() %>%
     as_tibble()
   
   return(child_records)
@@ -516,7 +581,7 @@ combine_parent_and_child_resultsets <- function(parents_df, child_df_list){
   if(is.tbl(child_df_list)){
     child_df_list <- list(child_df_list)
   }
-  bind_rows(
+  safe_bind_rows(
     lapply(1:nrow(parents_df), 
            FUN=function(x, y, z){
              parent_record <- y[x,]
@@ -536,6 +601,32 @@ combine_parent_and_child_resultsets <- function(parents_df, child_df_list){
     ))
 }
 
+#' Stack data frames which may have differing types in the same column
+#'
+#' This function accepts a list of data frames and will stack them all and
+#' return a \code{tbl_df} with missing values filled in and all columns stacked
+#' regardless of if the datatypes were different within the same column.
+#'
+#' @importFrom dplyr as_tibble
+#' @importFrom data.table rbindlist
+#' @param l \code{list}; A list containing data frames or lists that can be coerced 
+#' to data frames.
+#' @param fill \code{logical}; \code{TRUE} fills missing columns with NA
+#' (default \code{TRUE}). When \code{TRUE}, use.names is set to \code{TRUE}.
+#' @param idcol \code{character}; Creates a column in the result showing which
+#' list item those rows came from. TRUE names this column ".id". idcol="file"
+#' names this column "file".
+#' @param ... arguments passed to \code{\link[data.table]{rbindlist}}
+#' @return \code{tbl_df}; all list elements stacked on top of each other to
+#' form a single data frame
+#' @note This function is meant to be used internally. Only use when debugging.
+#' @keywords internal
+#' @export
+safe_bind_rows <- function(l, fill=TRUE, idcol=NULL, ...){
+  rbindlist(l = l, fill = fill, idcol = idcol, ...) %>%
+    as_tibble()
+}
+
 #' Extract tibble based on the "records" element of a list
 #' 
 #' This function accepts a list representing the parsed JSON recordset In this 
@@ -557,8 +648,8 @@ records_list_to_tbl <- function(x,
                                 object_name_as_col = FALSE){
   resultset <- x %>% 
     drop_attributes(object_name_append, object_name_as_col) %>%
-    drop_attributes_recursively() %>% 
-    drop_empty_recursively() %>% 
+    drop_attributes_recursively() %>%
+    drop_empty_recursively() %>%
     map_df(flatten_tbl_df)
   
   return(resultset)
@@ -582,6 +673,12 @@ records_list_to_tbl <- function(x,
 #' @keywords internal
 #' @export
 bind_query_resultsets <- function(resultset, next_records){
+  
+  deprecate_warn("0.2.2", "salesforcer::bind_query_resultsets()", "safe_bind_rows()",
+                 details = paste0("Consider safe_bind_rows() which silently combines ",
+                                  "all columns regardless if there are mixed datatypes ",
+                                  "in a single column."))
+  
   resultset <- tryCatch({
     bind_rows(resultset, next_records)  
   }, error=function(e){
